@@ -105,7 +105,7 @@ class SettingsDialog(QDialog, QtEventListener):
         nz.valueChanged.connect(on_nz)
 
         # lightning
-        help_trampoline = _(messages.MSG_HELP_TRAMPOLINE)
+        help_trampoline = messages.MSG_HELP_TRAMPOLINE
         trampoline_cb = QCheckBox(_("Use trampoline routing"))
         trampoline_cb.setToolTip(messages.to_rtf(help_trampoline))
         trampoline_cb.setChecked(not bool(self.config.get('use_gossip', False)))
@@ -287,7 +287,7 @@ class SettingsDialog(QDialog, QtEventListener):
             val = block_ex_custom_e.text()
             try:
                 val = ast.literal_eval(val)  # to also accept tuples
-            except:
+            except Exception:
                 pass
             self.config.set_key('block_explorer_custom', val)
         block_ex_custom_e.editingFinished.connect(on_be_edit)
